Developer guide
===============

This section describes the ``dlis-writer`` implementation in more detail.
The different types of logical records are explained.
Further, the principles of converting the Python objects to DLIS-compliant bytes are described.


.. toctree::
   :maxdepth: 3

   logicalandvisiblerecords
   lrtypes/index.rst
   attributes/index.rst
   writingfile/index.rst
